---
title: Strategy
---

# Strategy

```{eval-rst}
.. autoclass:: qtrade.backtest.Strategy
```

## Methods
```{eval-rst}
.. automethod:: qtrade.backtest.Strategy.init
.. automethod:: qtrade.backtest.Strategy.next
.. automethod:: qtrade.backtest.Strategy.buy
.. automethod:: qtrade.backtest.Strategy.sell
```